"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createModuleIdHOF = exports.defaultFactory = void 0;
var path_1 = __importDefault(require("path"));
var pathSep = path_1.default.sep;
function defaultFactory() {
    var fileToIdMap = new Map();
    var nextId = 0;
    return function (modulePath) {
        var id = fileToIdMap.get(modulePath);
        if (typeof id !== 'number') {
            id = nextId++;
            fileToIdMap.set(modulePath, id);
        }
        return id;
    };
}
exports.defaultFactory = defaultFactory;
var caches = new Map();
var getId = function (modulePath, projectRoot, SDKAlias) {
    var genSDKReg = function (SDKNames) {
        var uniformNames = SDKNames.map(function (x) { return x.replace('/', '_'); });
        return new RegExp("node_modules_(".concat(uniformNames.join('|'), ")"), 'ig');
    };
    //RN JS 全部以 RN_ 开头
    if (modulePath.includes('node_modules' + pathSep + 'react-native' + pathSep + 'Libraries' + pathSep)) {
        return "RN_".concat(path_1.default.basename(modulePath, '.js'));
    }
    // 如果模块不在 projectRoot 内, 比如 metro-runtime/src/polyfills/requires.js
    // id 变成了 _Users_simon_Developer_huya_hyext_node-pack_node_modules_metro-runtime_src_polyfills_require
    // 为了能正确过滤basebundle中已有的模块(node_modules_metro-runtime_src_polyfills_require), 需要进行处理
    var name = [projectRoot, process.env.MATRIX_SHARE_PROJECT_RN_ROOT, process.env.MATRIX_PACKER_ROOT]
        .filter(Boolean)
        .reduce(function (acc, cur) {
        return acc.replace("".concat(cur, "/"), '');
    }, modulePath);
    // remove .js extendtion
    name = name.replace(/.js$/, '');
    // 路径分隔符换成 _
    var regExp = pathSep == '\\' ? new RegExp('\\\\', 'g') : new RegExp(pathSep, 'g');
    name = name.replace(regExp, '_');
    // 把业务/base jsbundle 里的非 node_modules 里的模块 id 都带上根目录名
    if (modulePath.includes(projectRoot) && !modulePath.includes('node_modules')) {
        name = path_1.default.basename(projectRoot) + '_' + name;
    }
    Object.entries(SDKAlias).forEach(function (_a) {
        var alias = _a[0], SDKNames = _a[1];
        if (SDKNames.length <= 0)
            return;
        var SDKReg = genSDKReg(SDKNames);
        if (SDKReg.test(name)) {
            name = name.replace(SDKReg, alias);
        }
    });
    return name;
};
function createModuleIdHOF(_a) {
    var projectRoot = _a.projectRoot, _b = _a.SDKAlias, SDKAlias = _b === void 0 ? {} : _b;
    return function createModuleIdFactory() {
        return function (modulePath) {
            var cacheId = caches.get(modulePath);
            if (cacheId)
                return cacheId;
            var id = getId(modulePath, projectRoot, SDKAlias);
            caches.set(modulePath, id);
            return id;
        };
    };
}
exports.createModuleIdHOF = createModuleIdHOF;
